@@ -261,7 +261,12 @@ class MySQLHandler:
         except ImportError:
             return False
         args = { 'SecurityPin' : pin }
+        #figure out whether 0.24+ or 0.23
         try:
-            db_base = MythTV.MythDBBase(args=args)
+            method = getattr(MythTV, "MythDBBase")
+        except AttributeError:
+            method = getattr(MythTV, "MythDB")
+        try:
+            db_base = method(args=args)
         except Exception, e:
             return str(e)
